@@ -8,7 +8,7 @@
 
 # Contact
 # eemh1@st-andrews.ac.uk
-
+#
 # Emma E. M. Hobbs,
 # Biomolecular Sciences Building,
 # University of St Andrews,
@@ -42,24 +42,22 @@
 
 import re
 import subprocess
+import logging
 
 from tqdm import tqdm
+from typing import List, Optional
 
 from saintBioutils.utilities.file_io import make_output_directory
-from saintBioutils.utilities.file_io import get_paths
+from saintBioutils.utilities.file_io.get_paths import get_file_paths
 
 from cazomevolve import closing_message
-from cazomevolve.utilities.parsers.invoke_dbcan_parser import build_parser
 
 
-def main():
-    parser = build_parser()
-    args = parser.parse_args()
-
+def main(args: Optional[List[str]] = None, logger: Optional[logging.Logger] = None):
     make_output_directory(args.output_dir, args.force, args.nodelete)
 
     # get the path to every FASTA to be parsed by dbCAN
-    fasta_files_paths = list(set(get_paths.get_file_paths(args.input_dir, suffixes=['fasta', 'faa'])))
+    fasta_files_paths = list(set(get_file_paths(args.input_dir, suffixes=['fasta', 'faa'])))
     fasta_files_paths.sort()
     print(f"Retrieved {len(fasta_files_paths)} fasta files from {args.input_dir}")
 
@@ -67,12 +65,15 @@ def main():
         # define path to output dir that will house output for this specific input FASTA file
         # extract genomic accession from the file name, and name output dir after the accession
         try:
-            genomic_accession = re.findall(r"GCa_\d+\.\d+", fasta_path.name)[0]
+            genomic_accession = re.findall(r"GCF_\d+\.\d{1,5}", fasta_path.name)[0]
         except IndexError:
             try:
-                genomic_accession = re.findall(r"GCF_\d+\.\d+", fasta_path.name)[0]
+                genomic_accession = re.findall(r"GCA_\d+\.\d{1,5}", fasta_path.name)[0]
             except IndexError:
-                print(f"Could not get find genomic accession in {fasta_path.name}\nSkipping assembly\n")
+                logger.warning(
+                    f"Could not retrieve genomic accession from\n{fasta_path}\n"
+                    "Skipping FASTA file"
+                )
                 continue
         
         output_dir = args.output_dir / genomic_accession
@@ -83,7 +84,7 @@ def main():
 
         invoke_dbcan(fasta_path, output_dir, args)
 
-    closing_message('Invoke dbCAN')
+    closing_message('Invoke dbCAN', args)
 
 
 def invoke_dbcan(input_path, out_dir, args):
@@ -98,7 +99,7 @@ def invoke_dbcan(input_path, out_dir, args):
     # make the output directory
     make_output_directory(out_dir, True, False)
 
-    if args.version_2:
+    if args.dbcan_version == 2:
         # create list of args to invoke run_dbCAN
         dbcan_args = [
             "run_dbcan.py",
@@ -108,6 +109,26 @@ def invoke_dbcan(input_path, out_dir, args):
             str(out_dir),
         ]
 
+    elif args.dbcan_version == 3:
+        # create list of args to invoke run_dbCAN
+        dbcan_args = [
+            "run_dbcan",
+            str(input_path),
+            "protein",
+            "--out_dir",
+            str(out_dir),
+            "--stp_cpu",
+            str(args.cpu),
+            "--tf_cpu",
+            str(args.cpu),
+            "--eCAMI_jobs",
+            str(args.cpu),
+            "--hmm_cpu",
+            str(args.cpu),
+            "--dia_cpu",
+            str(args.cpu),
+        ]
+
     else:
         # create list of args to invoke run_dbCAN
         dbcan_args = [
@@ -117,15 +138,13 @@ def invoke_dbcan(input_path, out_dir, args):
             "--out_dir",
             str(out_dir),
             "--stp_cpu",
-            "8",
+            str(args.cpu),
             "--tf_cpu",
-            "8",
-            "--eCAMI_jobs",
-            "8",
+            str(args.cpu),
             "--hmm_cpu",
-            "8",
+            str(args.cpu),
             "--dia_cpu",
-            "8",
+            str(args.cpu),
         ]
 
     with open(f"{out_dir}/dbcan.log", "w+") as fh:
