@@ -38,40 +38,29 @@
 # SOFTWARE.
 """Retrieve all genomic assembly accessions descendent from a taxonomy node"""
 
+
 import logging
 import re
 import time
 
+from pathlib import Path
 from typing import List, Optional
 
 from socket import timeout
 from Bio import Entrez
 from saintBioutils.utilities.file_io import make_output_directory
-from saintBioutils.utilities.logger import config_logger
 from tqdm import tqdm
 from urllib.request import urlopen
 from urllib.error import HTTPError, URLError
 
 from cazomevolve import closing_message
-from cazomevolve.utilities.parsers.download_genomes_parser import build_parser
 
 
-def main(argv: Optional[List[str]] = None, logger: Optional[logging.Logger] = None):
+def main(args: Optional[List[str]] = None, logger: Optional[logging.Logger] = None):
     """Coordinate the retrieval of protein annotations from GenBank (.gbff) files.
     Including building parser, logger and output directory.
     Return dataframe of protein data.
     """
-    if argv is None:
-        parser = build_parser()
-        args = parser.parse_args()
-    else:
-        parser = build_parser(argv)
-        args = parser.parse_args()
-
-    if logger is None:
-        config_logger(args)
-    logger = logging.getLogger(__name__)
-
     make_output_directory(args.output_dir, args.force, args.nodelete)
 
     Entrez.email = args.email
@@ -189,7 +178,7 @@ def get_tax_ids(uid_list, term, args):
                 accession_data[accession_number_v] = batch_result['DocumentSummarySet']['DocumentSummary'][index]['AssemblyName']
 
     for accession in tqdm(accession_data, desc=f"Downloading genomes for {term}"):
-        for file_type in ((args.file_types).split(",")):
+        for file_type in args.file_types:
             download_file(
                 accession_number=accession,
                 assembly_name=accession_data[accession],
@@ -237,7 +226,7 @@ def entrez_retry(entrez_func, *func_args, **func_kwargs):
 
 
 def download_file(
-    accession_number, assembly_name, file_type, args, url_prefix="ftp://ftp.ncbi.nlm.nih.gov/genomes/all"
+    accession_number, assembly_name, file_type, args, url_prefix="https://ftp.ncbi.nlm.nih.gov/genomes/all"
 ):
     """Download file.
 
@@ -250,7 +239,7 @@ def download_file(
     """
     logger = logging.getLogger(__name__)
 
-    if args.genbank:   # retrieve GenBank not RefSeq
+    if args.database == 'genbank':   # retrieve GenBank not RefSeq
         gbk_accession = accession_number.replace("GCF_", "GCA_")
     else:  # retrieve RefSeq not GenBank
         gbk_accession = accession_number.replace("GCA_", "GCF_")
@@ -266,7 +255,7 @@ def download_file(
     if unzipped_path.exists():
         logger.warning(f"Output file {unzipped_path} exists, not downloading")
         return
-    
+
     escape_characters = re.compile(r"[\s/,#\(\)]")
     escape_name = re.sub(escape_characters, "_", assembly_name)
 
@@ -285,7 +274,7 @@ def download_file(
         response = urlopen(genbank_url, timeout=args.timeout)
     except (HTTPError, URLError, timeout) as e:
         logger.error(
-            f"Failed to download {file_type} for {accession_number}", exc_info=1,
+            f"Failed to download {file_type} for {accession_number}\nURL: {genbank_url}", exc_info=1,
         )
         return
     file_size = int(response.info().get("Content-length"))
